Module keyvalue

Key-Value Store Data Types

This module contains data types for the tea:keyvalue capability provider

Structs

AddRequest
A request to perform an atomic add operation
AddResponse
Result of an atomic add operation
DelRequest
A request to delete a key
DelResponse
GetRequest
A request to get a single value from the K/V store
GetResponse
The result of a get request
KeyExistsQuery
Test for the existence of a key
KeyVecGetQuery
Query KeyVec to get return Vec from Sorted Vec
KeyVecGetResponse
Response of KeyVecGetQuery
KeyVecInsertQuery
Insert a Tuple into Sorted Vec. using sorted key
KeyVecInsertResponse
Response to a set query, add, or delete
KeyVecTailOffQuery
Cut the Softed Vec to remain size. Drop off the tail if the vec is longer than remaining length
KeyVecTailOffResponse
Response to a set query, add, or delete
ListClearRequest
A request to clear a list at a given key
ListDelItemRequest
A request to delete all occurences of an item from a list
ListPushRequest
A request to add an item to the end of a list
ListRangeRequest
A request to retrieve a range of values from a list
ListRangeResponse
List of values returned from a range request
ListResponse
Return response from non-range list requests like push and clear
SetAddRequest
Request to add an item to a set
SetIntersectionRequest
Request for the intersection of multiple sets
SetOperationResponse
Response to a set query, add, or delete
SetQueryRequest
Request to query the contents of a set
SetQueryResponse
Response to an operation that requests members of a list (query, intersect, union)
SetRemoveRequest
Request to remove a specific value from a set
SetRequest
A request to set a value
SetResponse
Response to a set request
SetUnionRequest
Request for the union of multiple sets

Constants

OP_ADD
OP_CLEAR
OP_DEL
OP_GET
OP_KEYVEC_GET
OP_KEYVEC_INSERT
OP_KEYVEC_TAILOFF
OP_KEY_EXISTS
OP_LIST_DEL
OP_PUSH
OP_RANGE
OP_SET
OP_SET_ADD
OP_SET_INTERSECT
OP_SET_QUERY
OP_SET_REMOVE
OP_SET_UNION